<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Geçmiş veritabanı hazırlanıyor...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Geçmiş</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>Veritabanı açma başarısız. Hata mesajı:
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Qt kütüphanesi seçtiğiniz veritabanı tarafından desteklenmediği görünüyor. Lütfen Qt ile %1 eklentisini kurun.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Geçmiş dosyası yeni yerine kopyalanıyor: %1...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>Geçmiş dosyası yeni yerine kopyalanamıyor. Disk dolu olabilir kontrol edin.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>Veritabanı açılamıyor: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>Geçmiş dosyası bozulmuş, kurtarma gerçekleştiriliyor...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Kurtama tamamlandı.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>Kurtarma başarısız: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>Geçmiş dosyası zaman aşımına uğramış, yükleme gerçekleştiriliyor...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Yükleme tamamlandı.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Kopyalama tamamlandı.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>Hata yok.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>sqlite3 uygulaması bulunamadı.</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>Hatalı kurtarma kodu çağırımı.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>Bozuk veritabanı okunamıyor.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>Yedek dosyası oluşturulamıyor. Disk dolu olabilir.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>Kurtarma kodu bulunamadı veya çalıştırılamadı.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Veritabanı kurtarılırken bilinmeyen hata meydana geldi.</translation>
    </message>
</context>
</TS>